/*
 * @(#)$Id: TypeIncubator.java,v 1.11 2001/05/10 23:02:42 Bear Exp $
 *
 * Copyright 2001 Sun Microsystems, Inc. All Rights Reserved.
 * 
 * This software is the proprietary information of Sun Microsystems, Inc.  
 * Use is subject to license terms.
 * 
 */
package org.relaxng.datatype;

import java.util.Map;
import java.util.Vector;
import java.util.Iterator;

/**
 * creates an user-defined type by adding parameters to the pre-defined type.
 * 
 * @author <a href="mailto:kohsuke.kawaguchi@eng.sun.com">Kohsuke KAWAGUCHI</a>
 */
public interface DataTypeBuilder {
	
	/** adds a new parameter.
	 *
	 * @param name
	 *		the name of the parameter to be added.
	 * @param strValue
	 *		the raw value of the parameter. Caller may not normalize this value.
	 * @param context
	 *		The context information which can be used by the implementation to
	 *		acquire additional information. This context object is valid only
	 *		during this method call. The implementations may not keep the reference
	 *		to this object.
	 * @exception	DataTypeException
	 *		when the given parameter is inappropriate for some reason.
	 */
	void add( String name, String strValue, ValidationContext context )
		throws DataTypeException;
	
	/**
	 * derives a new datatype from a datatype by parameters that were already set.
	 * 
	 * @exception DataTypeException
	 *		DataTypeException is thrown if the derivation is somehow invalid.
	 *		For example, required parameter is missing, etc.
	 */
	DataType derive() throws DataTypeException;
}
